# Inferencni modul pro reseni ulohy o preliti vody mezi nadobami
# Obsahuje tridy pro reprezentaci stavu nadob, akci s nadobami a zpracovane stavy
#
# Autor: Miloš Barborka
# Verze: 1.0

from Data.stav_nadob import StavNadob
from Data.nadoba import Nadoba

from Data.Akce.Naplneni import Naplneni
from Data.Akce.Vyliti import Vyliti
from Data.Akce.Preliti import Preliti

from Znalosti.akce_nadoby import AkceNadoby

from Znalosti.zpracovane_stavy import ZpracovaneStavy

from Komunikace.komunikacni_modul import *


class Inference:

    def __init__(self):
        self.zpracovane_stavy = ZpracovaneStavy()

    def generuj_stavy(self, stav: StavNadob):
        """
        Generuje stavy nadob
        :param stav: je postaveni jednotlivych nadob
        :return: vraci stavy nadob
        """
        stavy = []

        for i in range(len(stav.nadoby)):
            # Vyliti nadoby
            aktualni_stav = stav.copy()
            AkceNadoby.vylij(aktualni_stav.nadoby[i])
            aktualni_stav.akce.append(Vyliti(i))
            stavy.append(aktualni_stav)

            # Plne naplneni nadoby
            aktualni_stav = stav.copy()
            AkceNadoby.napln(aktualni_stav.nadoby[i])
            aktualni_stav.akce.append(Naplneni(i))
            stavy.append(aktualni_stav)

        for i in range(len(stav.nadoby)):
            for j in range(len(stav.nadoby)):
                if i != j:
                    aktualni_stav = stav.copy()
                    AkceNadoby.prelij(aktualni_stav.nadoby[i], aktualni_stav.nadoby[j])
                    aktualni_stav.akce.append(Preliti(i, j))
                    stavy.append(aktualni_stav)

        return stavy

    def pridej_stavy_do_fronty(self, aktualni_stav, fronta_stavu):
        """
        Pridava stavy nadob do fronty
        :param aktualni_stav: aktualni stav nadob
        :param fronta_stavu: stavy dane do fronty
        :return:
        """
        generovane_stavy = self.generuj_stavy(aktualni_stav)

        for stav in generovane_stavy:
            # Podivat se, jestli se stav uz zpracoval - pokud ano, tak to preskocim
            if not self.zpracovane_stavy.obsahuje_stav(stav):
                fronta_stavu.append(stav)

    def start(self):
        """
        Slouzi pro cely beh programu
        :return: vraci true pokud chceme v behu pokracovat, false pokud ne
        """
        nadoby = beh_vypisu_zacatek()
        fronta_stavu = []

        vychozi_stav = StavNadob([Nadoba(nadoba[0], nadoba[1]) for nadoba in nadoby.values()])
        koncovy_stav = StavNadob([Nadoba(nadoba[2], nadoba[1]) for nadoba in nadoby.values()])
        # vychozi_stav = StavNadob([Nadoba(1, 3), Nadoba(0, 1), Nadoba(0, 2)])
        # koncovy_stav = StavNadob([Nadoba(0, 3), Nadoba(1, 1), Nadoba(1, 2)])


        vypis_vychoziho_stavu(vychozi_stav)

        self.zpracovane_stavy.pridat_stav(vychozi_stav)

        if vychozi_stav == koncovy_stav:
            print("Stavy jsou stejne")
            return

        self.pridej_stavy_do_fronty(vychozi_stav, fronta_stavu)

        while len(fronta_stavu) > 0:

            # Vzit prvni prvek z fronty
            stav = fronta_stavu.pop(0)

            if stav == koncovy_stav:
                vypis_postupu_reseni(stav)

                vypis_koncoveho_stavu(koncovy_stav)
                return

            self.zpracovane_stavy.pridat_stav(stav)
            self.pridej_stavy_do_fronty(stav, fronta_stavu)

        print("Neni mozne dosahnout koncoveho stavu")
        vypis_koncoveho_stavu(koncovy_stav)

        volba = input("Chcete vedet proc neni mozne dosahnout koncoveho stavu? ANO/NE\n").strip().upper()
        if volba == "ANO":
            vysvetleni_neuspechu(nadoby)

