# Vysvetlovaci modul slouzi k vysvetleni uzivateli, co ma program provadet.
# Vysvetlovaci modul obsahuje metody pro vypis hlavicky a vysvetlni odpovedi.
#
# Autor: Miloš Barborka
# Verze: 1.0
import math
from collections import deque


def vypis_hlavicky():
    print("--------------------------------------------------------------------------------------------------------")
    print("Tento program resi ulohu prelevani kapaliny se zdrojem a kanalem.")
    print("Program se uzivatele zepta na pocet nadob, ktere chce ve hre mit (2 az 4) a na par otazek ohledne nadob.")
    print("Otazky na nadoby budou ve tvaru: kolika ml je naplnena nadoba, kolika ml maximalne pojme a kolik ml ")
    print("chtete mit na konci. Vzdy zadate jen cisla bez jednotek, je to udelane obecne. Tyto otazky budou kladeny")
    print("pro kazdou nadobu.")
    print("--------------------------------------------------------------------------------------------------------")


def vypis_vychoziho_stavu(vychozi_stav):
    print(f"Vychozi stav: {vychozi_stav}")
    print("--------------------------------------------------------------------------------------------------------")


def vypis_postupu_reseni(stav):
    print(stav.ziskat_postup())


def vypis_koncoveho_stavu(koncovy_stav):
    print("--------------------------------------------------------------------------------------------------------")
    print(f"Koncovy stav: {koncovy_stav}")
    print("--------------------------------------------------------------------------------------------------------")


def vysvetleni_neuspechu(nadoby):
    """
    Poskytne vysvetleni, proc neni mozne dosahnout ciloveho stavu
    na zaklade soudelnosti, sudosti/lichosti a obecne dosazitelnosti.
    """
    # Kontrola sudosti a lichosti
    if obsahuji_nadoby_sude(nadoby) and obsahuji_nadoby_liche(nadoby):
        print("Nadoby obsahuji kombinaci sudych a lichych maximalnich objemu. "
              "Pokud je cilovy stav sudy i lichy, nelze jej dosahnout.")
    elif obsahuji_nadoby_sude(nadoby):
        for i, (naplneno, maximalne, koncovy_stav) in nadoby.items():
            if koncovy_stav % 2 != 0:
                print(f"Nadoby maji pouze sude maximalni objemy, ale nadoba {i + 1} pozaduje lichy cilovy stav {koncovy_stav}.")
                return
    elif obsahuji_nadoby_liche(nadoby):
        for i, (naplneno, maximalne, koncovy_stav) in nadoby.items():
            if koncovy_stav % 2 == 0:
                print(f"Nadoby maji pouze liche maximalni objemy, ale nadoba {i + 1} pozaduje sudy cilovy stav {koncovy_stav}.")
                return

    # Kontrola dosazitelnosti na zaklade nejvetsiho spolecneho delitele
    if not je_dosazitelny_gcd(nadoby):
        print("Ciloveho stavu nelze dosahnout, protoze cilove hodnoty nejsou nasobkem nejvetsiho spolecneho delitele "
              "objemu nadob.")
        return

    # Kontrola obecne dosazitelnosti
    if not je_dosazitelny_prakticky(nadoby):
        print("Ciloveho stavu nelze dosahnout, protoze pozadovane prelevani neni mozne s danymi pocatecnimi a "
              "maximalnimi objemy.")
        return

    # Pokud vse ostatni vyhovuje
    print("Vsechny pozadovane cilove stavy jsou dosazitelne.")


def obsahuji_nadoby_liche(nadoby):
    """Zkontroluje, zda nadoby obsahuji alespon jednu s lichym maximalnim objemem."""
    return any(maximalne % 2 != 0 for _, (_, maximalne, _) in nadoby.items())


def obsahuji_nadoby_sude(nadoby):
    """Zkontroluje, zda nadoby obsahuji alespon jednu se sudym maximalnim objemem."""
    return any(maximalne % 2 == 0 for _, (_, maximalne, _) in nadoby.items())


def je_dosazitelny_gcd(nadoby):
    """Zkontroluje dosazitelnost cilovych stavu na zaklade nejvetsiho spolecneho delitele."""
    objemy = [maximalne for _, (_, maximalne, _) in nadoby.items()]
    gcd = objemy[0]
    for objem in objemy[1:]:
        gcd = math.gcd(gcd, objem)

    for _, (_, _, koncovy_stav) in nadoby.items():
        if koncovy_stav % gcd != 0:
            return False
    return True


def je_dosazitelny_prakticky(nadoby):
    """
    Zkontroluje dosazitelnost cilovych stavu simulaci prelevani.
    Pouziva BFS k nalezeni cesty z pocatecniho stavu do ciloveho.
    """
    pocatecni = tuple(naplneno for _, (naplneno, _, _) in nadoby.items())
    cilovy = tuple(koncovy_stav for _, (_, _, koncovy_stav) in nadoby.items())
    kapacity = tuple(maximalne for _, (_, maximalne, _) in nadoby.items())

    # BFS fronta
    queue = deque([pocatecni])
    visited = set()
    visited.add(pocatecni)

    while queue:
        aktualni_stav = queue.popleft()

        if aktualni_stav == cilovy:
            return True

        for i in range(len(nadoby)):
            for j in range(len(nadoby)):
                if i == j:
                    continue

                # Prelit z i do j
                stav = list(aktualni_stav)
                mnozstvi = min(stav[i], kapacity[j] - stav[j])
                stav[i] -= mnozstvi
                stav[j] += mnozstvi
                novy_stav = tuple(stav)

                if novy_stav not in visited:
                    visited.add(novy_stav)
                    queue.append(novy_stav)

            # Naplnit nadobu z nevycerpatelneho zdroje
            stav = list(aktualni_stav)
            stav[i] = kapacity[i]
            novy_stav = tuple(stav)
            if novy_stav not in visited:
                visited.add(novy_stav)
                queue.append(novy_stav)

            # Vylit nadobu do kanalu
            stav = list(aktualni_stav)
            stav[i] = 0
            novy_stav = tuple(stav)
            if novy_stav not in visited:
                visited.add(novy_stav)
                queue.append(novy_stav)

    return False