"""
Author: Miroslav Bártík
Name of the program: Lloydova 15
Version: 1.0
date: 18.11.2024
description: This module is used primarily for communication with the user and for taking input from him
"""

from K_base import *

def pick_grid_size() -> int:
    """
    Function to prompt the user to pick a grid size

    :return: grid size
    """
    try:
        # Prompt for a valid grid size between 3 and 10
        print(f"Enter puzzle size (3 <= \033[93mN\033[0m <= 10): ", end="")
        n = int(input())
        if n < 3 or n > 10:
            # Notify the user if the size is out of bounds
            print("\033[91mInvalid size! The size must be between 3 and 10.\033[0m")
            print("-------------------------------------------------------------------------------")
            return pick_grid_size()  # Recursively prompt for a valid size
    except ValueError:
        # Notify the user if the input is not an integer
        print("\033[91mInvalid input! Please enter a valid integer.\033[0m")
        print("-------------------------------------------------------------------------------")
        return pick_grid_size()  # Recursively prompt for a valid size

    return n


def is_grid_generated() -> bool:
    """
    Function to determine whether the grid should be generated or user-defined

    :return: true if the grid should be generated, otherwise false
    """
    # Present the options to the user
    print("Please choose one of the following options:")
    print("\033[94m-------------------------------------------\033[0m")
    print("\033[93m1\033[0m. Define the grid yourself (enter your own puzzle).")
    print("\033[93m2\033[0m. Let the game generate a random puzzle for you.")
    print("\033[94m-------------------------------------------\033[0m")


    while True:
        # Prompt the user to choose an option
        print("Enter the number of your choice (\033[93m1\033[0m or \033[93m2\033[0m): ")
        try:
            answer = input()
            if answer == "1":
                return False  # User-defined grid
            elif answer == "2":
                return True  # Randomly generated grid
            else:
                # Notify the user if the input is invalid
                print("\033[91mInvalid input! Please enter 1 or 2.\033[0m")
                print("-------------------------------------------------------------------------------")
                continue  # Loop until a valid input is given
        except ValueError:
            # Handle unexpected input errors
            print("\033[91mInvalid input! Please enter 1 or 2.\033[0m")
            print("-------------------------------------------------------------------------------")
            continue  # Loop until a valid input is given



def load_user_grid(n: int):
    """
    Function to load a user-defined grid

    :param n: the size of the grid
    :return: the grid that the user entered
    """
    print(
        f"Please enter the grid row by row. Each row should have \033[93m{n}\033[0m elements: integers or one '\033[93mX\033[0m' (representing the gap).")
    grid = []
    gap_found = False  # To ensure only one 'X' is allowed

    for i in range(n):
        while True:
            try:
                # Prompt the user to input a row
                row = input(f"Enter row {i + 1} of {n}: ").split()

                # Ensure the row has exactly N elements
                if len(row) != n:
                    raise ValueError(f"Row must contain exactly {n} elements.")

                # Convert valid integers and check for the 'X'
                row_values = []
                for value in row:
                    if value == 'X' or value == 'x':
                        if gap_found:
                            raise ValueError("Only one 'X' is allowed in the entire grid.")
                        gap_found = True
                        row_values.append(0)
                    else:
                        row_values.append(int(value))  # Convert to integer

                grid.append(row_values)
                break  # Exit the loop if the row is valid
            except ValueError as e:
                print(f"\033[91mInvalid input: {e}. Please try again.\033[0m")
    # Ensure exactly one 'X' is present in the grid
    if not gap_found:
        print("\033[91mThe grid must contain exactly one 'X'. Please restart and input the grid again!\033[0m")
        print("-------------------------------------------------------------------------------")
        return load_user_grid(n)

    # Check if the grid is solvable
    if not is_solvable(grid):
        print("\033[91mThe grid you provided is not solvable. Please restart and input the grid again!\033[0m")
        print("-------------------------------------------------------------------------------")
        return load_user_grid(n)

    return grid  # Return the valid user-defined grid


def get_moves_count():
    """
    Function to get the number of moves for shuffling the grid

    :return: number of shuffling moves that the user entered
    """
    default_moves = 100
    while True:
        try:
            # Prompt the user to specify the number of shuffle moves
            print("Now you have the opportunity to influence the difficulty of the puzzle starting position.")
            user_input = input(f"Enter the number of moves to shuffle the puzzle (default: \033[93m{default_moves}\033[0m): ")

            # If the user doesn't input anything, use the default value
            if not user_input.strip():
                return default_moves

            # Convert the input to an integer
            moves_count = int(user_input)

            # Ensure the number of moves is valid
            if moves_count <= 0:
                raise ValueError("The number of moves must be a positive integer.")

            return moves_count
        except ValueError as e:
            # Notify the user of invalid input
            print(f"\033[91mInvalid input. {e} Please try again.\033[0m")
            print("-------------------------------------------------------------------------------")

def restart_app():
    """
    Function to determine if the user wants to restart the application

    :return: true if the user wants to restart the application, otherwise false
    """
    # Ask the user if they want to run the program again
    retry = input("\nDo you want to run the program again? (\033[93myes\033[0m/\033[93mno\033[0m): ").strip().lower()
    if retry not in ('yes', 'y'):
        print("Exiting the program. Goodbye!")
        return False
    else:
        return True
