"""
This class @Flight represents a flight in the airport knowledge-based system.
It includes attributes for the aircraft, arrival and departure times,
and a unique flight identifier.

Author:
    Václav Hajšman (hajsman2@student-zcu.cz)
Date:
    7.11.2024
Version:
    1.0
"""

from datetime import time
from DataStructures.Aircraft import Aircraft


class Flight:
    """
    Represents a flight in the system.

    Attributes:
        flightId (int): A unique identifier for the flight.
        aircraft (Aircraft): The Aircraft object associated with the flight.
        arrival (time): The arrival time of the flight.
        departure (time): The departure time of the flight.
    """
    flightId = 0  # Class-level variable to track unique flight IDs

    def __init__(self, aircraft: Aircraft, arrival: time, departure: time):
        """
        Initializes a Flight object.

        Parameters:
            aircraft (Aircraft): The Aircraft object for the flight.
            arrival (time): The arrival time of the flight.
            departure (time): The departure time of the flight.
        """
        self.aircraft = aircraft
        self.arrival = arrival
        self.departure = departure
        self.flightId = Flight.flightId  # Assign unique ID
        Flight.flightId += 1  # Increment the ID counter for the next flight

    def __str__(self) -> str:
        """
        Returns a string representation of the Flight object.

        The string includes the flight ID, aircraft name, and arrival/departure times.

        Returns:
            str: A formatted string describing the flight.
        """
        return (f"Let: [{self.flightId}] {self.aircraft.name}, "
                f"Přílet: {self.arrival.strftime('%H:%M')}, "
                f"Odlet: {self.departure.strftime('%H:%M')}")
