# -*- coding: utf-8 -*-
"""
Wolt Delivery Service Module
Author: Martin Riedl
Email: marty69@students.zcu.cz
Date: 13.12.2024
Version: 1.0

This module defines the Wolt delivery service data used in the shopping recommendation system. The
`store` dictionary contains information about the service's assortment and pricing. Delivery is always available.

Attributes:
    store (dict): A dictionary containing Wolt delivery service data, including assortment and pricing.
"""

store = {
    "name": "Wolt",
    "assortment": {
        "tofu": {"price": 180, "mnozstvi": 200, "jednotky": "g", "na_sklade": 300},
        "paprika": {"price": 140, "mnozstvi": 1, "jednotky": "ks", "na_sklade": 20},
        "orechy": {"price": 200, "mnozstvi": 100, "jednotky": "g", "na_sklade": 10},
        "arasidy": {"price": 130, "mnozstvi": 100, "jednotky": "g", "na_sklade": 0},
        "kari_pasta": {"price": 150, "mnozstvi": 50, "jednotky": "g", "na_sklade": 5},
        "kokosove_mleko": {"price": 160, "mnozstvi": 400, "jednotky": "ml", "na_sklade": 100},
        "tamari": {"price": 170, "mnozstvi": 0.2, "jednotky": "l", "na_sklade": 0},
        "olej": {"price": 145, "mnozstvi": 1, "jednotky": "l", "na_sklade": 30},
        "cukr": {"price": 110, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 80},
        "cesnek": {"price": 130, "mnozstvi": 1, "jednotky": "ks", "na_sklade": 15},
        "chilli": {"price": 135, "mnozstvi": 10, "jednotky": "g", "na_sklade": 0},
        "skrob": {"price": 140, "mnozstvi": 500, "jednotky": "g", "na_sklade": 50},
        "ryze": {"price": 120, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 300},
        "zelenina_mix": {"price": 150, "mnozstvi": 500, "jednotky": "g", "na_sklade": 60},
        "voda": {"price": 100, "mnozstvi": 10, "jednotky": "l", "na_sklade": 100},
        "dzus_pomerancovy": {"price": 160, "mnozstvi": 2, "jednotky": "l", "na_sklade": 5},
        "dzus_jablecny": {"price": 140, "mnozstvi": 1.5, "jednotky": "l", "na_sklade": 15},
        "cola": {"price": 135, "mnozstvi": 1, "jednotky": "l", "na_sklade": 0},
        "sprite": {"price": 150, "mnozstvi": 1.5, "jednotky": "l", "na_sklade": 25},
        "tonic": {"price": 145, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 0},
        "pivo": {"price": 190, "mnozstvi": 6, "jednotky": "ks", "na_sklade": 40},
        "vino_bile": {"price": 250, "mnozstvi": 1, "jednotky": "l", "na_sklade": 30},
        "vino_cervene": {"price": 270, "mnozstvi": 1, "jednotky": "l", "na_sklade": 20},
        "whisky": {"price": 650, "mnozstvi": 0.7, "jednotky": "l", "na_sklade": 10},
        "rum": {"price": 530, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 0},
        "vodka": {"price": 430, "mnozstvi": 1, "jednotky": "l", "na_sklade": 0},
        "kava": {"price": 220, "mnozstvi": 250, "jednotky": "g", "na_sklade": 50},
        "caj_cerny": {"price": 170, "mnozstvi": 100, "jednotky": "g", "na_sklade": 40},
        "caj_zeleny": {"price": 180, "mnozstvi": 100, "jednotky": "g", "na_sklade": 25},
        "energeticky_napoj": {"price": 150, "mnozstvi": 4, "jednotky": "ks", "na_sklade": 20},
        "mliko": {"price": 145, "mnozstvi": 2, "jednotky": "l", "na_sklade": 30},
        "smetana_do_kavy": {"price": 140, "mnozstvi": 0.25, "jednotky": "l", "na_sklade": 10},
        "mandlove_mleko": {"price": 165, "mnozstvi": 1, "jednotky": "l", "na_sklade": 0},
        "sojove_mleko": {"price": 160, "mnozstvi": 1, "jednotky": "l", "na_sklade": 15},
        "kakao": {"price": 155, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 0},
        "kokosova_voda": {"price": 170, "mnozstvi": 1, "jednotky": "l", "na_sklade": 10},
        "mineralka": {"price": 140, "mnozstvi": 1.5, "jednotky": "l", "na_sklade": 50},
        "mrazeny_hrasek": {"price": 150, "mnozstvi": 500, "jednotky": "g", "na_sklade": 10},
        "mrazeny_spenat": {"price": 145, "mnozstvi": 400, "jednotky": "g", "na_sklade": 30},
        "mrazeny_brokolice": {"price": 160, "mnozstvi": 300, "jednotky": "g", "na_sklade": 5},
        "zmrzlina_vanilkova": {"price": 180, "mnozstvi": 1, "jednotky": "l", "na_sklade": 20},
        "zmrzlina_cokoladova": {"price": 170, "mnozstvi": 0.75, "jednotky": "l", "na_sklade": 15},
        "mouka_hladka": {"price": 140, "mnozstvi": 2000, "jednotky": "g", "na_sklade": 100},
        "mouka_polohruba": {"price": 135, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 200},
        "mouka_ryzova": {"price": 145, "mnozstvi": 500, "jednotky": "g", "na_sklade": 0},
        "testoviny": {"price": 150, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 30},
        "kuskus": {"price": 145, "mnozstvi": 500, "jednotky": "g", "na_sklade": 50},
        "bulgur": {"price": 140, "mnozstvi": 500, "jednotky": "g", "na_sklade": 0},
        "olej_slunecnicovy": {"price": 170, "mnozstvi": 1.0, "jednotky": "l", "na_sklade": 15},
        "olej_olivovy": {"price": 190, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 0},
        "olej_kokosovy": {"price": 230, "mnozstvi": 5.0, "jednotky": "l", "na_sklade": 5},
        "ghi": {"price": 250, "mnozstvi": 500, "jednotky": "g", "na_sklade": 0},
        "brambory": {"price": 150, "mnozstvi": 150, "jednotky": "ks", "na_sklade": 300},
        "sojova_omacka": {"price": 180, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 30},
        "kecup": {"price": 160, "mnozstvi": 1.0, "jednotky": "l", "na_sklade": 80},
        "horcice": {"price": 150, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 20},
        "med": {"price": 230, "mnozstvi": 500, "jednotky": "g", "na_sklade": 40},
        "dzin": {"price": 350, "mnozstvi": 0.75, "jednotky": "l", "na_sklade": 10},
        "kakao_prasek": {"price": 160, "mnozstvi": 200, "jednotky": "g", "na_sklade": 15},
        "cornflakes": {"price": 180, "mnozstvi": 500, "jednotky": "g", "na_sklade": 50},
        "ovesne_vlocky": {"price": 170, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 20},
        "mrazena_zelenina": {"price": 190, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 60},
        "kroupy": {"price": 150, "mnozstvi": 500, "jednotky": "g", "na_sklade": 10},
        "cizrna": {"price": 170, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 0},
        "cocka": {"price": 160, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 25},
        "fazole": {"price": 175, "mnozstvi": 900, "jednotky": "g", "na_sklade": 250},
        "konzervovane_tunaky": {"price": 190, "mnozstvi": 5, "jednotky": "ks", "na_sklade": 100},
        "konzervovana_kukurice": {"price": 165, "mnozstvi": 3, "jednotky": "ks", "na_sklade": 50},
        "konzervovane_fazole": {"price": 170, "mnozstvi": 4, "jednotky": "ks", "na_sklade": 30},
        "cokolada_horka": {"price": 195, "mnozstvi": 200, "jednotky": "g", "na_sklade": 20},
        "cokolada_mlecna": {"price": 185, "mnozstvi": 200, "jednotky": "g", "na_sklade": 40},
        "susene_jahody": {"price": 250, "mnozstvi": 100, "jednotky": "g", "na_sklade": 15},
        "susene_svestky": {"price": 220, "mnozstvi": 200, "jednotky": "g", "na_sklade": 10},
        "rozinky": {"price": 180, "mnozstvi": 150, "jednotky": "g", "na_sklade": 0},
        "suchary": {"price": 160, "mnozstvi": 500, "jednotky": "g", "na_sklade": 100},
        "krekry": {"price": 170, "mnozstvi": 250, "jednotky": "g", "na_sklade": 50},
        "chipsy": {"price": 170, "mnozstvi": 300, "jednotky": "g", "na_sklade": 75},
        "sul": {"price": 130, "mnozstvi": 500, "jednotky": "g", "na_sklade": 200},
        "knedlik": {"price": 600, "mnozstvi": 1, "jednotky": "ks", "na_sklade": 200},
        "pepr_mlety": {"price": 150, "mnozstvi": 200, "jednotky": "g", "na_sklade": 25},
        "pepr_cely": {"price": 155, "mnozstvi": 100, "jednotky": "g", "na_sklade": 40},
        "paprika_sladka": {"price": 145, "mnozstvi": 150, "jednotky": "g", "na_sklade": 50},
        "paprika_stiplava": {"price": 150, "mnozstvi": 100, "jednotky": "g", "na_sklade": 0},
        "chilli_prasek": {"price": 160, "mnozstvi": 50, "jednotky": "g", "na_sklade": 10},
        "kurkuma": {"price": 140, "mnozstvi": 100, "jednotky": "g", "na_sklade": 20},
        "kari": {"price": 150, "mnozstvi": 200, "jednotky": "g", "na_sklade": 0},
        "oregano": {"price": 140, "mnozstvi": 50, "jednotky": "g", "na_sklade": 15},
        "majoranka": {"price": 140, "mnozstvi": 50, "jednotky": "g", "na_sklade": 20},
        "tymian": {"price": 140, "mnozstvi": 50, "jednotky": "g", "na_sklade": 10},
        "rozmaryn": {"price": 140, "mnozstvi": 50, "jednotky": "g", "na_sklade": 5},
        "bazalka": {"price": 140, "mnozstvi": 50, "jednotky": "g", "na_sklade": 10},
        "cesnek_suseny": {"price": 145, "mnozstvi": 100, "jednotky": "g", "na_sklade": 15},
        "cibule_susena": {"price": 145, "mnozstvi": 100, "jednotky": "g", "na_sklade": 10},
        "zazvor_mlety": {"price": 150, "mnozstvi": 50, "jednotky": "g", "na_sklade": 5},
        "hrebicek": {"price": 165, "mnozstvi": 30, "jednotky": "g", "na_sklade": 20},
        "skorice_mleta": {"price": 145, "mnozstvi": 100, "jednotky": "g", "na_sklade": 30},
        "skorice_cela": {"price": 150, "mnozstvi": 50, "jednotky": "g", "na_sklade": 0},
        "bobkovy_list": {"price": 140, "mnozstvi": 20, "jednotky": "g", "na_sklade": 40},
        "novy_koreni": {"price": 140, "mnozstvi": 50, "jednotky": "g", "na_sklade": 0},
        "vanilka_lusk": {"price": 280, "mnozstvi": 5, "jednotky": "ks", "na_sklade": 10},
        "vanilkovy_cukr": {"price": 135, "mnozstvi": 200, "jednotky": "g", "na_sklade": 50},
        "smes_provensalske": {"price": 145, "mnozstvi": 50, "jednotky": "g", "na_sklade": 30},
        "sojova_omacka": {"price": 150, "mnozstvi": 0.25, "jednotky": "l", "na_sklade": 20},
        "balzamovy_ocet": {"price": 170, "mnozstvi": 0.25, "jednotky": "l", "na_sklade": 15},
        "tabasco": {"price": 175, "mnozstvi": 0.06, "jednotky": "l", "na_sklade": 5},
        "wasabi": {"price": 185, "mnozstvi": 50, "jednotky": "g", "na_sklade": 10},
        "mlety_kmin": {"price": 140, "mnozstvi": 100, "jednotky": "g", "na_sklade": 25},
        "cely_kmin": {"price": 140, "mnozstvi": 100, "jednotky": "g", "na_sklade": 30},
        "kureci_prsa": {"price": 220, "mnozstvi": 300, "jednotky": "g", "na_sklade": 25},
        "kruti_prsa": {"price": 250, "mnozstvi": 500, "jednotky": "g", "na_sklade": 15},
        "veprove_kotlety": {"price": 240, "mnozstvi": 400, "jednotky": "g", "na_sklade": 20},
        "hovezi_maso": {"price": 280, "mnozstvi": 600, "jednotky": "g", "na_sklade": 10},
        "rybi_filety": {"price": 260, "mnozstvi": 300, "jednotky": "g", "na_sklade": 5},
        "slanina": {"price": 200, "mnozstvi": 200, "jednotky": "g", "na_sklade": 15},
        "sunka": {"price": 190, "mnozstvi": 150, "jednotky": "g", "na_sklade": 20},
        "parky": {"price": 165, "mnozstvi": 6, "jednotky": "ks", "na_sklade": 40},
        "vejce": {"price": 175, "mnozstvi": 12, "jednotky": "ks", "na_sklade": 50},
        "mleko": {"price": 145, "mnozstvi": 1.0, "jednotky": "l", "na_sklade": 300},
        "smetana": {"price": 150, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 50},
        "jogurt": {"price": 140, "mnozstvi": 500, "jednotky": "g", "na_sklade": 200},
        "mascarpone": {"price": 185, "mnozstvi": 250, "jednotky": "g", "na_sklade": 100},
        "ricotta": {"price": 175, "mnozstvi": 200, "jednotky": "g", "na_sklade": 75},
        "tvaroh": {"price": 155, "mnozstvi": 250, "jednotky": "g", "na_sklade": 150},
        "syr_eidam": {"price": 165, "mnozstvi": 300, "jednotky": "g", "na_sklade": 60},
        "parmazan": {"price": 225, "mnozstvi": 150, "jednotky": "g", "na_sklade": 20},
        "mozarella": {"price": 175, "mnozstvi": 125, "jednotky": "g", "na_sklade": 80},
        "mrkev": {"price": 135, "mnozstvi": 4, "jednotky": "ks", "na_sklade": 300},
        "celer": {"price": 140, "mnozstvi": 1, "jednotky": "ks", "na_sklade": 150},
        "rajcata": {"price": 155, "mnozstvi": 5, "jednotky": "ks", "na_sklade": 120},
        "okurka": {"price": 140, "mnozstvi": 1, "jednotky": "ks", "na_sklade": 200},
        "salat": {"price": 145, "mnozstvi": 1, "jednotky": "ks", "na_sklade": 90},
        "brokolice": {"price": 150, "mnozstvi": 1, "jednotky": "ks", "na_sklade": 80},
        "kvetak": {"price": 150, "mnozstvi": 1, "jednotky": "ks", "na_sklade": 60},
        "cibule": {"price": 135, "mnozstvi": 3, "jednotky": "ks", "na_sklade": 250},
        "jablka": {"price": 150, "mnozstvi": 6, "jednotky": "ks", "na_sklade": 180},
        "hrusky": {"price": 145, "mnozstvi": 4, "jednotky": "ks", "na_sklade": 130},
        "pomerance": {"price": 155, "mnozstvi": 3, "jednotky": "ks", "na_sklade": 110},
        "citron": {"price": 140, "mnozstvi": 2, "jednotky": "ks", "na_sklade": 200},
        "limetky": {"price": 140, "mnozstvi": 2, "jednotky": "ks", "na_sklade": 150},
        "kecup": {"price": 145, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 80},
        "horcice": {"price": 150, "mnozstvi": 0.3, "jednotky": "l", "na_sklade": 70},
        "sojova_omacka": {"price": 155, "mnozstvi": 0.2, "jednotky": "l", "na_sklade": 60},
        "vajecna_pasta": {"price": 175, "mnozstvi": 250, "jednotky": "g", "na_sklade": 50},
        "maslo": {"price": 185, "mnozstvi": 250, "jednotky": "g", "na_sklade": 40},
        "margarin": {"price": 175, "mnozstvi": 250, "jednotky": "g", "na_sklade": 30},
        "dzem": {"price": 165, "mnozstvi": 400, "jednotky": "g", "na_sklade": 20},
        "med": {"price": 210, "mnozstvi": 300, "jednotky": "g", "na_sklade": 10},
        "tatarka": {"price": 155, "mnozstvi": 0.2, "jednotky": "l", "na_sklade": 15},
        "majoneza": {"price": 160, "mnozstvi": 0.2, "jednotky": "l", "na_sklade": 15},
        "olivy": {"price": 175, "mnozstvi": 150, "jednotky": "g", "na_sklade": 20},
        "nakladane_okurky": {"price": 165, "mnozstvi": 300, "jednotky": "g", "na_sklade": 25},
        "kapary": {"price": 185, "mnozstvi": 50, "jednotky": "g", "na_sklade": 10},
        "kysane_zeli": {"price": 155, "mnozstvi": 500, "jednotky": "g", "na_sklade": 30},
        "slanina_platky": {"price": 210, "mnozstvi": 200, "jednotky": "g", "na_sklade": 15},
        "mrazeny_hrasek": {"price": 155, "mnozstvi": 500, "jednotky": "g", "na_sklade": 50},
        "mrazeny_spenat": {"price": 150, "mnozstvi": 400, "jednotky": "g", "na_sklade": 40},
        "mrazeny_brokolice": {"price": 160, "mnozstvi": 300, "jednotky": "g", "na_sklade": 30},
        "mrazene_rybi_filety": {"price": 215, "mnozstvi": 600, "jednotky": "g", "na_sklade": 20},
        "mrazeny_kureci_prsa": {"price": 245, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 100},
        "mrazeny_kvetak": {"price": 165, "mnozstvi": 400, "jednotky": "g", "na_sklade": 15},
        "mrazeny_mrkev": {"price": 145, "mnozstvi": 300, "jednotky": "g", "na_sklade": 25},
        "mrazene_jahody": {"price": 185, "mnozstvi": 500, "jednotky": "g", "na_sklade": 20},
        "mrazene_maliny": {"price": 195, "mnozstvi": 400, "jednotky": "g", "na_sklade": 10},
        "mrazene_boruvky": {"price": 210, "mnozstvi": 300, "jednotky": "g", "na_sklade": 15},
        "mrazene_svestky": {"price": 175, "mnozstvi": 400, "jednotky": "g", "na_sklade": 5},
        "zmrzlina_vanilkova": {"price": 225, "mnozstvi": 1, "jednotky": "l", "na_sklade": 10},
        "zmrzlina_cokoladova": {"price": 205, "mnozstvi": 0.75, "jednotky": "l", "na_sklade": 15},
        "mrazene_lasagne": {"price": 245, "mnozstvi": 1, "jednotky": "ks", "na_sklade": 5},
        "petrzel_koren": {"price": 120, "mnozstvi": 1, "jednotky": "ks", "na_sklade": 600},
        "mrazena_pizza": {"price": 275, "mnozstvi": 2, "jednotky": "ks", "na_sklade": 8},
        "mrazeny_bramborovy_hranolky": {"price": 175, "mnozstvi": 750, "jednotky": "g", "na_sklade": 30},
        "mrazene_pirohy": {"price": 185, "mnozstvi": 500, "jednotky": "g", "na_sklade": 20},
        "mrazene_maso": {"price": 325, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 15},
        "mrazene_chleba": {"price": 150, "mnozstvi": 1, "jednotky": "ks", "na_sklade": 25},
        "mrazene_bulky": {"price": 165, "mnozstvi": 4, "jednotky": "ks", "na_sklade": 20},
        "mrazene_rybi_prsty": {"price": 195, "mnozstvi": 300, "jednotky": "g", "na_sklade": 15},
        "mrazene_plody_mori": {"price": 250, "mnozstvi": 500, "jednotky": "g", "na_sklade": 200},
        "mrazene_gulase": {"price": 230, "mnozstvi": 2, "jednotky": "ks", "na_sklade": 100},
        "mrazene_ravioli": {"price": 185, "mnozstvi": 400, "jednotky": "g", "na_sklade": 80},
        "mrazene_susenky": {"price": 175, "mnozstvi": 250, "jednotky": "g", "na_sklade": 150},
        "voda": {"price": 135, "mnozstvi": 10, "jednotky": "l", "na_sklade": 500},
        "dzus_pomerancovy": {"price": 155, "mnozstvi": 2, "jednotky": "l", "na_sklade": 200},
        "dzus_jablecny": {"price": 150, "mnozstvi": 1.5, "jednotky": "l", "na_sklade": 180},
        "cola": {"price": 145, "mnozstvi": 1, "jednotky": "l", "na_sklade": 150},
        "sprite": {"price": 145, "mnozstvi": 1.5, "jednotky": "l", "na_sklade": 160},
        "tonic": {"price": 140, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 100},
        "pivo": {"price": 135, "mnozstvi": 6, "jednotky": "ks", "na_sklade": 300},
        "vino_bile": {"price": 225, "mnozstvi": 1, "jednotky": "l", "na_sklade": 80},
        "vino_cervene": {"price": 245, "mnozstvi": 1, "jednotky": "l", "na_sklade": 60},
        "whisky": {"price": 625, "mnozstvi": 0.7, "jednotky": "l", "na_sklade": 30},
        "rum": {"price": 425, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 25},
        "vodka": {"price": 325, "mnozstvi": 1, "jednotky": "l", "na_sklade": 40},
        "liker": {"price": 275, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 50},
        "kava": {"price": 205, "mnozstvi": 250, "jednotky": "g", "na_sklade": 90},
        "caj_cerny": {"price": 175, "mnozstvi": 100, "jednotky": "g", "na_sklade": 80},
        "caj_zeleny": {"price": 175, "mnozstvi": 100, "jednotky": "g", "na_sklade": 70},
        "energeticky_napoj": {"price": 165, "mnozstvi": 4, "jednotky": "ks", "na_sklade": 120},
        "mliko": {"price": 145, "mnozstvi": 2, "jednotky": "l", "na_sklade": 200},
        "smetana_do_kavy": {"price": 140, "mnozstvi": 0.25, "jednotky": "l", "na_sklade": 100},
        "mandlove_mleko": {"price": 160, "mnozstvi": 1, "jednotky": "l", "na_sklade": 90},
        "kakao": {"price": 150, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 120},
        "ledovy_caj": {"price": 145, "mnozstvi": 1.5, "jednotky": "l", "na_sklade": 150},
        "kokosova_voda": {"price": 155, "mnozstvi": 1, "jednotky": "l", "na_sklade": 100},
        "mineralka": {"price": 140, "mnozstvi": 1.5, "jednotky": "l", "na_sklade": 200},
        "perlive_vino": {"price": 275, "mnozstvi": 0.75, "jednotky": "l", "na_sklade": 80},
        "domaci_sirup": {"price": 175, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 60}
    },
    "open_from": (0, 0),
    "open_to": (23, 59),
    "distance": 0.0
}


# Extract the keys from the assortment
keys = list(store["assortment"].keys())

# Find duplicates using a dictionary to count occurrences
from collections import Counter

key_counts = Counter(keys)
duplicates = {key: count for key, count in key_counts.items() if count > 1}

# Output the duplicates
if duplicates:
    print("Duplicate keys found:")
    for key, count in duplicates.items():
        print(f"{key}: {count} times")
else:
    print("No duplicate keys found.")
