# -*- coding: utf-8 -*-
"""
Znalostní systém - Modul receptů (riedl_recipes)
Autor: Martin Riedl
Email: marty69@students.zcu.cz
Datum: 13.12.2024
Verze: 2.0

Popis:
Tento modul poskytuje funkcionalitu pro správu receptů v rámci znalostního systému na vaření.
Recepty jsou uloženy v externích souborech a tento modul je centralizuje do jednoho přístupového bodu.

Funkce modulu:
- Třída `Recipes`: Obsahuje a spravuje seznam receptů.
- Umožňuje vyhledávat recepty podle názvu.

Použití:
- Inicializace třídy `Recipes` načte všechny dostupné recepty do slovníku.
- Funkce `get_recipe(name)` vrátí požadovaný recept podle jeho názvu.

Importované moduly:
- riedl_data_base.recipes.*: Obsahuje jednotlivé recepty jako moduly.

Verze:
- 1.0: Základní implementace správy receptů.
- 2.0: Přidány nové recepty a strukturované uložení dat v externích souborech.
"""

from .riedl_data_base.recipes.kung_pao import recipe as kung_pao
from .riedl_data_base.recipes.curry import recipe as curry
from .riedl_data_base.recipes.bramboracky import recipe as bramboracky
from .riedl_data_base.recipes.svickova import recipe as svickova
from .riedl_data_base.recipes.vepro_knedlo_zelo import recipe as vepro_knedlo_zelo

class Recipes:
    """
    Třída pro správu receptů v systému.

    Atributy:
    - recipe_dict (dict): Slovník receptů, kde klíčem je název receptu a hodnotou je objekt receptu.

    Metody:
    - get_recipe(name): Vrací recept podle názvu.
    """
    def __init__(self):
        """
        Inicializuje třídu `Recipes` a načte dostupné recepty do slovníku.
        """
        self.recipe_dict = {
            'kung_pao': kung_pao,
            'curry': curry,
            'bramboracky': bramboracky,
            'svickova': svickova,
            'vepro_knedlo_zelo': vepro_knedlo_zelo
        }
    
    def get_recipe(self, name):
        """
        Vyhledává recept podle názvu.

        Parametry:
        - name (str): Název receptu.

        Návratová hodnota:
        - dict: Objekt receptu, pokud je nalezen; None jinak.
        """
        return self.recipe_dict.get(name, None)
