"""
Guide Module for Linear Equation Solver
Faiz Suleimanov
13.12.2024
version 1.0

This module provides user guidance and explanations for various steps in the Linear Equation Solver process.
It includes a comprehensive guide for getting started and detailed explanations for each key process step.
"""

def print_guide():
    print("""
Welcome to Linear Equation Solver!
================================

Quick Start Guide:
----------------
1. Run main.py
2. Enter variable names (separated by spaces)
   Example: x y z

3. Enter equations one by one
   Example: 2*x + 3*y - z = 5
   Type 'done' when finished

Rules for equations:
------------------
* Use * for multiplication: 2*x (not 2x)
* Use + or - between terms
* Put all variables on the left side of =
* Put only a number on the right side of =

Examples:
--------
Two variables:
    Variables: x y
    Equations: 
        2*x + y = 5
        x - y = 1

Three variables:
    Variables: x y z
    Equations:
        2*x + y - z = 3
        x - 2*y + 3*z = 1
        3*x + y + z = 7

Tips:
----
* Number of equations should equal number of variables
* Check your input before pressing Enter
* If you make a mistake, type 'done' and start over
* Watch each step of the solution process
""")


def explain_step(step_id, variable=None):
    """
    Provides an explanation for the given step in the Linear Equation Solver process.
    :param step_id: A string identifier for the step (e.g., "equation_input", "variable_elimination").
    :param variable: The current variable being processed (used for "variable_elimination").
    """
    explanations = {
        "variables_input":
            f"""In this step, you need to input the variables for your equations. 
             Enter the variable names separated by spaces (e.g., x y z). 
             These variables will be used throughout the system of equations.""",
        "equation_input":
            f"""In this step, you need to input your equations one by one. 
             Ensure all variables are on the left-hand side of the equation and constants on the right-hand side. 
             Use '*' for multiplication (e.g., 2*x). 
             Type 'done' when all equations are entered.""",
        "variable_elimination":
            f"""Currently, the system is eliminating the variable '{variable}'. 
             This step eliminates one variable at a time using substitution or elimination methods. 
             The goal is to simplify the system of equations to make it easier to solve. 
             Each variable is sequentially removed from the equations.
             For more details, see: https://en.wikipedia.org/wiki/Gaussian_elimination""",
    }

    explanation = explanations.get(step_id, "No explanation available for this step.")
    print(f"\nExplanation: {explanation}\n")
