"""
Knowledge Base Module for Linear Equation Solver
Faiz Suleimanov
13.12.2024
version 1.0

This module defines the `KnowledgeBase` class, which stores and manages facts and rules for the solver.
It provides methods to add, remove, and process facts and rules as part of the inference mechanism.
"""

class KnowledgeBase:
    def __init__(self):
        """
        Initialize an empty knowledge base with no facts or rules.
        """
        self.facts = []  #
        self.rules = []

    def add_fact(self, fact):
        """
        Add fact to knowledge base
        """
        if fact not in self.facts:
            self.facts.append(fact)

    def remove_fact(self, fact):
        """
        Remove fact from knowledge base.
        """
        if fact in self.facts:
            self.facts.remove(fact)

    def add_rule(self, rule):
        """
        Add rule to knowledge base.
        """
        self.rules.append(rule)

    def apply_rules(self):
        """
        Apply rules from queue.
        """
        while self.rules:
            rule = self.rules.pop(0)
            rule.apply(self)
        self._remove_duplicates()

    def find_facts_with_variable(self, var):
        """
        Return facts with special variable in it.
        """
        return [fact for fact in self.facts if var in fact.free_symbols]

    def _remove_duplicates(self):
        """
        Remove duplicates facts from knowledge base.
        """
        unique_facts = []
        for fact in self.facts:
            if fact not in unique_facts:
                unique_facts.append(fact)
        self.facts = unique_facts

    def reset(self):
        """
        Reset the knowledge base by clearing all facts and rules.
        """
        self.facts = []
        self.rules = []

    def __str__(self):
        """
        Str representation of the facts.
        """
        return "\n".join([str(fact) for fact in self.facts])
