"""
**************************************************
Projekt: Semestralni prace - Hra NIM
Autor: Josef Zetek
E-Mail: jzetek24@students.zcu.cz
Datum: 16.12.2024
Popis: Program nacte pocet hromadek a pocet
       sirek v hromadkach. Nasledne se hraje duel
       uzivatele s pocitacem, kde ma uzivatel
       moznost zvolit si napovedu, ktera mu poradi
       optimalni tah.
**************************************************
"""

# Importuje modul pro regularni vyrazy
import re
from Explanation.Explanation import Explanation


class CommunicationModule:

    @staticmethod
    def user_choice(attribute_name, choices, help_text):
        """
        Zobrazi uzivateli moznosti a vyzada od nej vyber jedne z nich.
        :param attribute_name: Název vybíraného atributu
        :param choices:
        :param help:
        :return: Vrátí
        """


        # Vypise seznam moznosti
        print("Vyberte si jednu z nabizenych moznosti pro {} zadanim cisla volby: ".format(attribute_name))
        for i in range(len(choices)):
            print("{}) {}".format(i + 1, choices[i]))

        print("{}) Napoveda".format(len(choices) + 1))

        while True:
            selection = input("\nZadejte cislo volby: ")
            # Pokud uzivatel zada neciselny vstup
            if not re.match(r"^\d+$", selection):
                Explanation.show_explanation("Spatny vstup, priklad vstupu:\n1 pro volbu cislo 1)")
                continue

            selection = int(selection)
            if selection == len(choices) + 1:
                Explanation.show_explanation(help_text)
                continue

            # Pokud je vyber v platnem rozsahu
            if 1 <= selection <= len(choices):
                return selection

            Explanation.show_explanation(
                "Spatny vstup, zadejte cislo mezi 1 a {}, případně nápovědu {}.".format(len(choices), len(choices) + 1))

    @staticmethod
    def numeric_input(attribute_name, help_text):
        """
        Zobrazi zpravu a vyzada od uzivatele ciselny vstup. Zajisti, ze vstup bude cele kladne cislo.
        """
        while True:
            value = input(f"Zadejte {attribute_name}, pripadne h pro vysvetleni, co delat: ")

            if value.lower() == "h":
                Explanation.show_explanation(help_text)
                continue

            if not re.match(r"^\d+$", value) or int(value) <= 0:
                Explanation.show_explanation("Spatny vstup, zadejte cele kladne cislo.")
                continue
            # Pokud je vstup platny, vrati ho jako cele cislo
            return int(value)

    @staticmethod
    def numeric_input_bounded(attribute_name, help_text, lower_bound, upper_bound):
        """
        Zobrazi zpravu a vyzada od uzivatele ciselny vstup. Zajisti, ze vstup bude cele cislo v danem rozsahu.
        """
        while True:
            value = input(f"Zadejte {attribute_name} pripadne h pro vysvetleni, co delat: ")

            if value.lower() == "h":
                Explanation.show_explanation(help_text)
                continue

            if not re.match(r"^\d+$", value) or int(value) <= 0:
                Explanation.show_explanation("Spatny vstup, zadejte cele kladne cislo.")
                continue

            if int(value) < lower_bound or int(value) > upper_bound:
                Explanation.show_explanation(f"Spatny vstup, zadejte cele cislo v rozsahu {lower_bound} az {upper_bound}.")
                continue

            return int(value)

    @staticmethod
    def string_input(attribute_name: str) -> str:
        """
        Funkce ziska od uzivatele retezec, ktery neni prazdny
        :param attribute_name: Jmeno atributu k informaci pro uzivatele co bude zadavat
        :return: Vraci retezece, ktery uzivatel zadal
        """
        while True:

            text = input(f"Zadejte {attribute_name}: ")

            if len(text) > 0:
                return text

            Explanation.show_explanation("Spatny vstup, zadejte neprazdny retezec.")

    @staticmethod
    def write_output(message):
        """
        Prints out a message
        """
        print(f"{message}")
